/*
 * Copyright (C) 2013 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef endlesstunnel_simplegeom_hpp
#define endlesstunnel_simplegeom_hpp

#include "indexbuf.hpp"
#include "vertexbuf.hpp"

// Convenience class that represents a geometry in terms of a
// vertex buffer + index buffer.
class SimpleGeom {
    public:
        VertexBuf *vbuf;
        IndexBuf *ibuf;

        inline SimpleGeom() {
            vbuf = NULL;
            ibuf = NULL;
        }

        inline SimpleGeom(VertexBuf *vb, IndexBuf *ib) {
            vbuf = vb;
            ibuf = ib;
        }

        inline SimpleGeom(VertexBuf *vb) {
            vbuf = vb;
            ibuf = NULL;
        }

        inline ~SimpleGeom() {
            if (vbuf) {
                delete vbuf;
            }
            if (ibuf) {
                delete ibuf;
            }
        }
};

#endif

